# ontologize
Code to leverage insight from marked up historical sources


## Build package

`python3 -m build` - builds objects in `dist`

Note that this hasn't been pushed to PyPI or similar, stopped following the tutorial [here](https://packaging.python.org/en/latest/tutorials/packaging-projects/#uploading-the-distribution-archives).

Created a pypi account (lemhop), added api token to ~/.pypirc.

ERROR    HTTPError: 403 Forbidden from https://upload.pypi.org/legacy/                                                              
         The user 'lemhop' isn't allowed to upload to project 'ontologize'. See https://pypi.org/help/#project-name for more        
         information. 

https://packaging.python.org/en/latest/guides/publishing-package-distribution-releases-using-github-actions-ci-cd-workflows/